@@ -132,6 +132,16 @@ class NetworkInstance(Instance):  # pylint: disable=too-many-instance-attributes
                 f"is_external_network={self.is_external_network}, "
                 f"orchestration_status={self.orchestration_status})")
 
+    @classmethod
+    def get_all_url(cls) -> str:  # pylint: disable=arguments-differ
+        """Return url to get all networks.
+
+        Returns:
+            str: Url to get all networks
+
+        """
+        return f"{cls.base_url}{cls.api_version}/network/l3-networks/"
+
     @property
     def url(self) -> str:
         """Network instance url.
@@ -184,14 +194,17 @@ class NetworkInstance(Instance):  # pylint: disable=too-many-instance-attributes
                    operational_status=api_response.get("operational-status"),
                    is_trunked=api_response.get("is-trunked"))
 
-    def delete(self) -> "NetworkDeletionRequest":
+    def delete(self, a_la_carte: bool = True) -> "NetworkDeletionRequest":
         """Create network deletion request.
 
         Send request to delete network instance
 
+        Args:
+            a_la_carte (boolean): deletion mode
+
         Returns:
             NetworkDeletionRequest: Deletion request
 
         """
         self._logger.debug("Delete %s network", self.network_id)
-        return NetworkDeletionRequest.send_request(self)
+        return NetworkDeletionRequest.send_request(self, a_la_carte)
