@@ -11,8 +11,11 @@
 AAI_URL         = "https://aai.api.sparky.simpledemo.onap.org:30233"
 AAI_API_VERSION = "v20"
 AAI_AUTH        = "Basic QUFJOkFBSQ=="
+AAI_BULK_CHUNK  = 30
 CDS_URL         = "http://portal.api.simpledemo.onap.org:30449"
 CDS_AUTH        = ("ccsdkapps", "ccsdkapps")
+CPS_URL         = "http://portal.api.simpledemo.onap.org:8080"
+CPS_AUTH        = ("cpsuser", "cpsr0cks!")
 MSB_URL         = "https://msb.api.simpledemo.onap.org:30283"
 SDC_BE_URL      = "https://sdc.api.be.simpledemo.onap.org:30204"
 SDC_FE_URL      = "https://sdc.api.fe.simpledemo.onap.org:30207"
@@ -48,3 +51,8 @@ DCAEMOD_GUI_SERVICE = f"{DCAEMOD_URL}/"
 HOLMES_GUI_SERVICE = f"{HOLMES_URL}/iui/holmes/default.html"
 POLICY_GUI_SERVICE = f"{POLICY_URL}/onap/login.html"
 POLICY_CLAMP_GUI_SERVICE = f"{CLAMP_URL}/"
+
+# VID OBJECTS DEFAULT VALUES
+PROJECT = "Onapsdk_project"
+LOB = "Onapsdk_lob"
+PLATFORM = "Onapsdk_platform"
