@@ -378,6 +378,11 @@ class SdcResource(SdcOnboardable, ABC):  # pylint: disable=too-many-instance-att
             self.submit()
             time.sleep(self._time_wait)
             self.onboard()
+        elif self.status == const.CHECKED_IN:
+            # Checked in status check added
+            self.certify()
+            time.sleep(self._time_wait)
+            self.onboard()
         elif self.status == const.CERTIFIED:
             self.load()
 
@@ -728,6 +733,27 @@ class SdcResource(SdcOnboardable, ABC):  # pylint: disable=too-many-instance-att
         msg = f"SDC resource {sdc_resource.name} is not a component"
         raise ResourceNotFound(msg)
 
+    def get_component_by_name(self, component_name: str) -> Component:
+        """Get resource's component by it's name.
+
+        Get component by name.
+
+        Args:
+            component_name (str): Component's name
+
+        Raises:
+            ResourceNotFound: Component with given name does not exist
+
+        Returns:
+            Component: Component object
+
+        """
+        for component in self.components:
+            if component.sdc_resource.name == component_name:
+                return component
+        msg = f"SDC resource {component_name} is not a component"
+        raise ResourceNotFound(msg)
+
     def declare_input_for_own_property(self, property_obj: Property) -> None:
         """Declare input for resource's property.
 
@@ -874,3 +900,51 @@ class SdcResource(SdcOnboardable, ABC):  # pylint: disable=too-many-instance-att
         result = self._action_to_sdc(const.CHECKOUT, "lifecycleState")
         if result:
             self.load()
+
+    def undo_checkout(self) -> None:
+        """Undo Checkout SDC resource."""
+        self._logger.debug("Undo Checkout %s SDC resource", self.name)
+        result = self._action_to_sdc(const.UNDOCHECKOUT, "lifecycleState")
+        if result:
+            self.load()
+
+    def certify(self) -> None:
+        """Certify SDC resource."""
+        self._logger.debug("Certify %s SDC resource", self.name)
+        result = self._action_to_sdc(const.CERTIFY, "lifecycleState")
+        if result:
+            self.load()
+
+    def add_resource(self, resource: 'SdcResource') -> None:
+        """
+        Add a Resource.
+
+        Args:
+            resource (SdcResource): the resource to add
+
+        """
+        if self.status == const.DRAFT:
+            url = "{}/{}/{}/resourceInstance".format(self._base_create_url(),
+                                                     self._sdc_path(),
+                                                     self.unique_identifier)
+
+            template = jinja_env().get_template(
+                "add_resource_to_service.json.j2")
+            data = template.render(resource=resource,
+                                   resource_type=resource.origin_type)
+            result = self.send_message("POST",
+                                       f"Add {resource.origin_type} to {self.origin_type}",
+                                       url,
+                                       data=data)
+            if result:
+                self._logger.info("Resource %s %s has been added on %s %s",
+                                  resource.origin_type, resource.name,
+                                  self.origin_type, self.name)
+                return result
+            self._logger.error(("an error occured during adding resource %s %s"
+                                " on %s %s in SDC"),
+                               resource.origin_type, resource.name,
+                               self.origin_type, self.name)
+            return None
+        msg = f"Can't add resource to {self.origin_type} which is not in DRAFT status"
+        raise StatusError(msg)
